@@ -99,10 +99,15 @@ class PSD:
         result: bool = False
         print("Check validity for command " + command)
 
+        countg = command.count("g")
+        countG = command.count("G")
+        print("g in command appears " + str(countg) + " times")
+        print("G in command appears " + str(countG) + " times")
+
         if "cmdError" not in command:
             commandType = self.getTypeOfCommand(command)
             if (commandType == 0b0010 or commandType == 0b0100 or commandType == 0b0001) and \
-                    self.checkGgPairs(self.command.command_g_counter, self.command.command_G_counter):
+                    self.checkGgPairs(countg, countG):
                 result = True
             else:
                 print()
